@@ -1,5 +1,6 @@
 #' @title Contaminants in MS
 #' @description check the possible contaminants
+#' @author Yonghui Dong
 #' @param mz suspected m/z value
 #' @param ppm mass tolerance, default value = 10
 #' @param mode ionization mode, either positive '+' or negative '-'
@@ -9,10 +10,16 @@
 #'  contam(44.998, ppm = 10, mode = '-')
 
 contam <- function (mz, ppm = 10, mode = c('+', '-')) {
+
+  ##(1) input check
   if(is.numeric(mz) == FALSE) {stop("Warning: mass to charge ratio mz shoule be numeric!")}
   if(mode != "+" & mode !="-") {stop("WARNING: ion mode invalid. Choose '+' or '-'.\n")}
+
+  ##(2) load database
   contam_pos <- as.data.frame(sysdata$contam_pos)
   contam_neg <- as.data.frame(sysdata$contam_neg)
+
+  ##(3) search in database
   expand.grid.df <- function(...) Reduce(function(...) merge(..., by=NULL),
                                          list(...))
   if(mode == '-') {
@@ -20,20 +27,18 @@ contam <- function (mz, ppm = 10, mode = c('+', '-')) {
     colnames(contam.list)[1] <- 'mymz'
     myppm <- with(contam.list, abs(mymz - mz) * 10^6 / mz)
     Result = contam.list[(myppm <= ppm), -1]
-    if(nrow(Result) != 0) {
-      return(Result)
-    } else
-      message('Not Found')
-  } else if (mode == '+') {
+  } else{
     contam.list <- expand.grid.df(mz, contam_pos)
     colnames(contam.list)[1] <- 'mymz'
     myppm <- with(contam.list, abs(mymz - mz) * 10^6 / mz)
     Result = contam.list[(myppm <= ppm), -1]
-    if(nrow(Result) != 0) {
-      return(Result)
-    } else
-      message('Not Found, Unknown')
-   }
+  }
+
+  ##(4) return results
+  if(nrow(Result) != 0) {
+    return(Result)
+  } else
+    message('Not Found, Unknown')
  }
 
 
